@@ -24,7 +24,7 @@ import sys
 
 import click
 
-from platformio import exception
+from platformio import exception, proc
 from platformio.compat import IS_WINDOWS
 
 
@@ -41,7 +41,7 @@ class cd(object):
 
 
 def get_source_dir():
-    curpath = os.path.realpath(__file__)
+    curpath = os.path.abspath(__file__)
     if not os.path.isfile(curpath):
         for p in sys.path:
             if os.path.isfile(os.path.join(p, __file__)):
@@ -119,7 +119,7 @@ def ensure_udev_rules():
     if not any(os.path.isfile(p) for p in installed_rules):
         raise exception.MissedUdevRules
 
-    origin_path = os.path.realpath(
+    origin_path = os.path.abspath(
         os.path.join(get_source_dir(), "..", "scripts", "99-platformio-udev.rules")
     )
     if not os.path.isfile(origin_path):
@@ -146,33 +146,40 @@ def path_endswith_ext(path, extensions):
 
 
 def match_src_files(src_dir, src_filter=None, src_exts=None, followlinks=True):
-    def _append_build_item(items, item, src_dir):
+    def _add_candidate(items, item, src_dir):
         if not src_exts or path_endswith_ext(item, src_exts):
             items.add(os.path.relpath(item, src_dir))
 
+    def _find_candidates(pattern):
+        candidates = set()
+        for item in glob.glob(
+            os.path.join(glob.escape(src_dir), pattern), recursive=True
+        ):
+            if not os.path.isdir(item):
+                _add_candidate(candidates, item, src_dir)
+                continue
+            for root, dirs, files in os.walk(item, followlinks=followlinks):
+                for d in dirs if not followlinks else []:
+                    if os.path.islink(os.path.join(root, d)):
+                        _add_candidate(candidates, os.path.join(root, d), src_dir)
+                for f in files:
+                    _add_candidate(candidates, os.path.join(root, f), src_dir)
+        return candidates
+
     src_filter = src_filter or ""
     if isinstance(src_filter, (list, tuple)):
         src_filter = " ".join(src_filter)
 
-    matches = set()
+    result = set()
     # correct fs directory separator
     src_filter = src_filter.replace("/", os.sep).replace("\\", os.sep)
     for (action, pattern) in re.findall(r"(\+|\-)<([^>]+)>", src_filter):
-        items = set()
-        for item in glob.glob(
-            os.path.join(glob.escape(src_dir), pattern), recursive=True
-        ):
-            if os.path.isdir(item):
-                for root, _, files in os.walk(item, followlinks=followlinks):
-                    for f in files:
-                        _append_build_item(items, os.path.join(root, f), src_dir)
-            else:
-                _append_build_item(items, item, src_dir)
+        candidates = _find_candidates(pattern)
         if action == "+":
-            matches |= items
+            result |= candidates
         else:
-            matches -= items
-    return sorted(list(matches))
+            result -= candidates
+    return sorted(list(result))
 
 
 def to_unix_path(path):
@@ -181,6 +188,25 @@ def to_unix_path(path):
     return re.sub(r"[\\]+", "/", path)
 
 
+def normalize_path(path):
+    path = os.path.abspath(path)
+    if not IS_WINDOWS or not path.startswith("\\\\"):
+        return path
+    try:
+        result = proc.exec_command(["net", "use"])
+        if result["returncode"] != 0:
+            return path
+        share_re = re.compile(r"\s([A-Z]\:)\s+(\\\\[^\s]+)")
+        for line in result["out"].split("\n"):
+            share = share_re.search(line)
+            if not share:
+                continue
+            path = path.replace(share.group(2), share.group(1))
+    except OSError:
+        pass
+    return path
+
+
 def expanduser(path):
     """
     Be compatible with Python 3.8, on Windows skip HOME and check for USERPROFILE
