@@ -20,6 +20,7 @@ import sys
 from datetime import date
 
 from platformio import __core_packages__, exception, fs, util
+from platformio.exception import UserSideException
 from platformio.package.exception import UnknownPackageError
 from platformio.package.manager.tool import ToolPackageManager
 from platformio.package.meta import PackageItem, PackageSpec
@@ -37,11 +38,11 @@ def get_installed_core_packages():
     return result
 
 
-def get_core_package_dir(name, auto_install=True):
+def get_core_package_dir(name, spec=None, auto_install=True):
     if name not in __core_packages__:
         raise exception.PlatformioException("Please upgrade PlatformIO Core")
     pm = ToolPackageManager()
-    spec = PackageSpec(
+    spec = spec or PackageSpec(
         owner="platformio", name=name, requirements=__core_packages__[name]
     )
     pkg = pm.get_package(spec)
@@ -54,17 +55,15 @@ def get_core_package_dir(name, auto_install=True):
     return pm.get_package(spec).path
 
 
-def update_core_packages(only_check=False, silent=False):
+def update_core_packages():
     pm = ToolPackageManager()
     for name, requirements in __core_packages__.items():
         spec = PackageSpec(owner="platformio", name=name, requirements=requirements)
-        pkg = pm.get_package(spec)
-        if not pkg:
-            continue
-        if not silent or pm.outdated(pkg, spec).is_outdated():
-            pm.update(pkg, spec, only_check=only_check)
-    if not only_check:
-        remove_unnecessary_core_packages()
+        try:
+            pm.update(spec, spec)
+        except UnknownPackageError:
+            pass
+    remove_unnecessary_core_packages()
     return True
 
 
@@ -101,7 +100,7 @@ def remove_unnecessary_core_packages(dry_run=False):
     return candidates
 
 
-def inject_contrib_pysite(verify_openssl=False):
+def inject_contrib_pysite():
     # pylint: disable=import-outside-toplevel
     from site import addsitedir
 
@@ -119,12 +118,10 @@ def inject_contrib_pysite(verify_openssl=False):
     addsitedir(contrib_pysite_dir)
     sys.path.insert(0, contrib_pysite_dir)
 
-    if not verify_openssl:
-        return True
-
     try:
         # pylint: disable=import-error,unused-import,unused-variable
         from OpenSSL import SSL
+
     except:  # pylint: disable=bare-except
         build_contrib_pysite_package(contrib_pysite_dir)
 
@@ -152,8 +149,15 @@ def build_contrib_pysite_package(target_dir, with_metadata=True):
     ]
     if "linux" in systype:
         args.extend(["--no-binary", ":all:"])
-    for dep in get_contrib_pysite_deps():
-        subprocess.check_call(args + [dep])
+    try:
+        subprocess.run(args + get_contrib_pysite_deps(), check=True, env=os.environ)
+    except subprocess.CalledProcessError as exc:
+        if "linux" in systype:
+            raise UserSideException(
+                "\n\nPlease ensure that the next packages are installed:\n\n"
+                "sudo apt install python3-dev libffi-dev libssl-dev\n"
+            )
+        raise exc
 
     # build manifests
     with open(
@@ -206,37 +210,19 @@ def build_contrib_pysite_package(target_dir, with_metadata=True):
 
 
 def get_contrib_pysite_deps():
-    sys_type = util.get_systype()
-    py_version = "%d%d" % (sys.version_info.major, sys.version_info.minor)
-
-    twisted_version = "20.3.0"
-    result = [
-        "twisted == %s" % twisted_version,
-    ]
-
-    # twisted[tls], see setup.py for %twisted_version%
-    result.extend(
-        [
+    systype = util.get_systype()
+    twisted_version = "22.1.0"
+    if "linux_arm" in systype:
+        result = [
+            # twisted[tls], see setup.py for %twisted_version%
+            "twisted == %s" % twisted_version,
             # pyopenssl depends on it, use RUST-less version
             "cryptography >= 3.3, < 35.0.0",
-            "pyopenssl >= 16.0.0",
-            "service_identity >= 18.1.0",
-            "idna >= 0.6, != 2.3",
+            "pyopenssl >= 16.0.0, <= 21.0.0",
+            "service_identity >= 18.1.0, <= 21.1.0",
         ]
-    )
-
-    if "windows" in sys_type:
-        result.append("pypiwin32 == 223")
-        # workaround for twisted wheels
-        twisted_wheel = (
-            "https://download.lfd.uci.edu/pythonlibs/x2tqcw5k/Twisted-"
-            "%s-cp%s-cp%s-win%s.whl"
-            % (
-                twisted_version,
-                py_version,
-                py_version,
-                "_amd64" if "amd64" in sys_type else "32",
-            )
-        )
-        result[0] = twisted_wheel
+    else:
+        result = ["twisted[tls] == %s" % twisted_version]
+    if "windows" in systype:
+        result.append("pywin32 != 226")
     return result
